@@ -139,9 +139,9 @@ class Executor:
         return execution_details
 
     def execute(self, rule_id, incremental=False, sleep_interval=5, total_retries=0,
-                failure_strategy: FailureStrategy = FailureStrategy.DoNotFail, pipeline_run_id=None):
+                failure_strategy: FailureStrategy = FailureStrategy.DoNotFail):
         try:
-            execution_obj = self.exec_call(rule_id=rule_id, incremental=incremental, pipeline_run_id=pipeline_run_id)
+            execution_obj = self.exec_call(rule_id=rule_id, incremental=incremental)
             self.id = execution_obj.id
             if self.sync:
                 self.get_execution_result(self.id, sleep_interval, total_retries, failure_strategy)
