@@ -1,6 +1,6 @@
 class AssetType:
 
-    def __init__(self, id=None, name=None, canProfile=None, canSample=None):
+    def __init__(self, id=None, name=None, canProfile=None, canSample=None, *args, **kwargs):
         """
             Description:
                 Asset type supported in torch. like table, views, database et cetera.
