@@ -1,7 +1,7 @@
 
 class Notification:
 
-    def __init__(self, associatedItemId, associatedItemType, createdAt, eventType, id, metadata: dict, title):
+    def __init__(self, associatedItemId, associatedItemType, createdAt, eventType, id, metadata: dict, title, *args, **kwargs):
         self.title = title
         self.metadata = metadata
         self.id = id
@@ -19,7 +19,7 @@ class Notification:
 
 class Incident:
 
-    def __init__(self, associatedItemId, associatedItemType, id, metadata: dict, raisedAt, resolver, sentTo, title, type):
+    def __init__(self, associatedItemId, associatedItemType, id, metadata: dict, raisedAt, resolver, sentTo, title, type, *args, **kwargs):
         self.type = type
         self.title = title
         self.sentTo = sentTo
